import { ErrorTypeKeys, ReportIds, } from './interfaces';
export class AbstractOptionsManager {
    checkReport(key) {
        return this.checks.reports[key];
    }
    checkType(key) {
        return this.checks.types[key];
    }
    checkMode() {
        return this.checks.mode;
    }
    checkRequirements() {
        return this.checks.requirements;
    }
    updateReport(key, value) {
        this.checks.reports[key] = value;
        this.saveKey('report-' + key, value, true);
    }
    updateType(key, value) {
        this.checks.types[key] = value;
        this.saveKey('type-' + key, value, true);
    }
    updateMode(mode) {
        this.checks.mode = mode;
        this.saveKey('mode', mode, true);
    }
    updateRequirements(req) {
        this.checks.requirements = req;
        this.saveKey('requirements', req, true);
    }
    // initialize options, will NOT change notebook metadata
    initializeOptions(checks) {
        this.checks = checks;
    }
    reloadOptions() {
        this.initializeOptions({
            mode: this.loadKey('mode', this.default.mode),
            requirements: this.loadKey('requirements', this.default.requirements),
            reports: ReportIds.reduce((previous, key) => {
                const rkey = 'report-' + key;
                previous[key] = this.loadKey(rkey, this.default.reports[key]);
                return previous;
            }, Object.assign({}, this.default.reports)),
            types: ErrorTypeKeys.reduce((previous, key) => {
                const tkey = 'type-' + key;
                previous[key] = this.loadKey(tkey, this.default.types[key]);
                return previous;
            }, Object.assign({}, this.default.types)),
        });
    }
    saveOptions() {
        this.saveKey('mode', this.checks.mode, false);
        this.saveKey('requirements', this.checks.requirements, false);
        for (const key of ErrorTypeKeys) {
            this.saveKey('type-' + key, this.checks.types[key], false);
        }
        for (const key of ReportIds) {
            this.saveKey('report-' + key, this.checks.reports[key], false);
        }
    }
}
