import { ISessionContext } from '@jupyterlab/apputils';
import { Cell } from '@jupyterlab/cells';
import { IDocumentManager } from '@jupyterlab/docmanager';
import { CellType, IBaseCell } from '@jupyterlab/nbformat';
import { Notebook, NotebookPanel } from '@jupyterlab/notebook';
import { IReport, IJulynterLintOptions } from '../linter/interfaces';
import { NotebookHandler } from './notebookhandler';
export declare const IExperimentConfigAttributes: readonly ["lintingMessages", "lintingTypes", "execution", "activity", "code", "name", "enabled"];
export declare type IExperimentConfigAttribute = typeof IExperimentConfigAttributes[number];
export declare type IExperimentConfig = {
    [id in IExperimentConfigAttribute]: boolean | 'maybe';
};
export declare class ExperimentManager {
    config: IExperimentConfig;
    lastLint: {
        [id: string]: IReport[];
    };
    constructor(docmanager: IDocumentManager);
    private _overrideJupyterLab;
    reportRename(oldName: string, newName: string): void;
    reportSplitCell(oldIndex: number, notebook: Notebook): void;
    reportMergeCell(toMerge: number[], notebook: Notebook): void;
    reportIndexesAction(indexes: number[], notebook: Notebook, operation: string): void;
    reportChangeCellType(index: number, oldValue: CellType, newValue: CellType, notebook: Notebook): void;
    reportPaste(index: number, toInsert: IBaseCell[], toDelete: number[], mode: string, notebook: Notebook): void;
    reportAction(notebook: Notebook, operation: string): void;
    reportLoadConfig(nbPanel: NotebookPanel, checks: IJulynterLintOptions): void;
    reportSaveConfig(nbPanel: NotebookPanel, checks: IJulynterLintOptions): void;
    reportCloseNotebook(handler: NotebookHandler): void;
    reportKernelActivity(handler: NotebookHandler, operation: string, kernelName: string): void;
    reportActivity(handler: NotebookHandler, operation: string): void;
    reportVisibility(handler: NotebookHandler, visible: boolean): void;
    reportSetConfig(nbPanel: NotebookPanel, config: string, value: boolean | string): void;
    reportNotebookKernel(handler: NotebookHandler, kernel: string, language: string): void;
    reportNotebookCode(handler: NotebookHandler): void;
    reportExecution(cell: Cell, sessionContext: ISessionContext): void;
    reportLinting(handler: NotebookHandler, reports: IReport[]): void;
    reportFeedback(handler: NotebookHandler, report: IReport, message: string): void;
    reportLintClick(handler: NotebookHandler, report: IReport): void;
    private selectMessages;
    private selectTypes;
    private _collectCell;
    private _getActiveIndexes;
    private _notebookName;
    private _send;
}
