import { AbstractOptionsManager } from '../linter/options';
export class OptionsManager extends AbstractOptionsManager {
    constructor(nbPanel, config, environmentManager, errorHandler, update) {
        super();
        this.default = config.defaultOptions;
        this._experimentManager = environmentManager;
        this._eh = errorHandler;
        this._nbPanel = nbPanel;
        this._update = update;
        this.initializeOptions(Object.assign({}, this.default));
        this.reloadOptions();
    }
    loadKey(key, def) {
        try {
            let result = def;
            if (this._nbPanel) {
                const temp = this._nbPanel.model.metadata.get('julynter-check-' + key);
                if (temp !== undefined && temp !== null) {
                    result = temp;
                }
            }
            return result;
        }
        catch (error) {
            throw this._eh.report(error, 'OptionsManager:loadKey', [key, def]);
        }
    }
    saveKey(key, value, ereport = true) {
        try {
            if (this._nbPanel) {
                this._nbPanel.model.metadata.set('julynter-check-' + key, value);
                if (ereport) {
                    this._experimentManager.reportSetConfig(this._nbPanel, key, value);
                }
            }
            this._update();
        }
        catch (error) {
            throw this._eh.report(error, 'OptionsManager:loadKey', [
                key,
                value,
                ereport,
            ]);
        }
    }
    // initialize options, will NOT change notebook metadata
    initializeOptions(checks) {
        try {
            super.initializeOptions(checks);
            this._update();
        }
        catch (error) {
            throw this._eh.report(error, 'OptionsManager:initializeOptions', [
                checks,
            ]);
        }
    }
    reloadOptions() {
        try {
            super.reloadOptions();
            this._experimentManager.reportLoadConfig(this._nbPanel, this.checks);
        }
        catch (error) {
            throw this._eh.report(error, 'OptionsManager:reloadOptions', []);
        }
    }
    saveOptions() {
        try {
            super.saveOptions();
            this._experimentManager.reportSaveConfig(this._nbPanel, this.checks);
            this._update();
        }
        catch (error) {
            throw this._eh.report(error, 'OptionsManager:saveOptions', []);
        }
    }
}
